@@ -44,7 +44,9 @@
 #include <locale>
 #include <cstring>
 
-#ifdef HAVE_SYS_ERRNO_H
+#ifdef __OpenBSD__
+#include <errno.h>
+#elif defined(HAVE_SYS_ERRNO_H)
 #include <sys/errno.h>
 #endif
 #include <gtkmm/fileselection.h>
@@ -1352,6 +1354,9 @@ App::App(const synfig::String& basepath, int *argc, char ***argv):
 		dock_keyframes=new studio::Dock_Keyframes();
 		dock_manager->register_dockable(*dock_keyframes);
 
+//! Must be done before Dock_Timetrack and Dock_Curves :
+//! both are connected to a studio::LayerTree::param_tree_view_'s signal, and
+//! studio::LayerTree is created from Dock_Layers::init_canvas_view_vfunc
 		studio_init_cb.task(_("Init Layers..."));
 		dock_layers=new studio::Dock_Layers();
 		dock_manager->register_dockable(*dock_layers);
@@ -2271,7 +2276,8 @@ App::dialog_save_file(const std::string &title, std::string &filename, std::stri
 	{
 		file_type_enum = manage(new Widget_Enum());
 		file_type_enum->set_param_desc(ParamDesc().set_hint("enum")
-				.add_enum_value(synfig::RELEASE_VERSION_0_64_1, "0.64.1", strprintf("0.64.1 (%s)", _("current")))
+				.add_enum_value(synfig::RELEASE_VERSION_0_64_2, "0.64.2", strprintf("0.64.2 (%s)", _("current")))
+				.add_enum_value(synfig::RELEASE_VERSION_0_64_1, "0.64.1", "0.64.1")
 				.add_enum_value(synfig::RELEASE_VERSION_0_64_0, "0.64.0", "0.64.0")
 				.add_enum_value(synfig::RELEASE_VERSION_0_63_04, "0.63.05", "0.63.05")
 				.add_enum_value(synfig::RELEASE_VERSION_0_63_04, "0.63.04", "0.63.04")
