@@ -110,7 +110,7 @@ public:
 		set_tile_h(warm_target->get_tile_h());
 		set_canvas(warm_target->get_canvas());
 		set_quality(warm_target->get_quality());
-		set_remove_alpha(warm_target->get_remove_alpha());
+		set_alpha_mode(warm_target->get_alpha_mode());
 		set_threads(warm_target->get_threads());
 		set_clipping(warm_target->get_clipping());
 		set_rend_desc(&warm_target->rend_desc());
@@ -295,7 +295,7 @@ public:
 		set_tile_h(warm_target->get_tile_h());
 		set_canvas(warm_target->get_canvas());
 		set_quality(warm_target->get_quality());
-		set_remove_alpha(warm_target->get_remove_alpha());
+		set_alpha_mode(warm_target->get_alpha_mode());
 		set_threads(warm_target->get_threads());
 		set_clipping(warm_target->get_clipping());
 		set_rend_desc(&warm_target->rend_desc());
@@ -455,7 +455,7 @@ public:
 		set_avoid_time_sync(warm_target->get_avoid_time_sync());
 		set_canvas(warm_target->get_canvas());
 		set_quality(warm_target->get_quality());
-		set_remove_alpha(warm_target->get_remove_alpha());
+		set_alpha_mode(warm_target->get_alpha_mode());
 		set_threads(warm_target->get_threads());
 		set_rend_desc(&warm_target->rend_desc());
 		alive_flag=true;
@@ -584,7 +584,7 @@ public:
 		set_avoid_time_sync(warm_target->get_avoid_time_sync());
 		set_canvas(warm_target->get_canvas());
 		set_quality(warm_target->get_quality());
-		set_remove_alpha(warm_target->get_remove_alpha());
+		set_alpha_mode(warm_target->get_alpha_mode());
 		set_rend_desc(&warm_target->rend_desc());
 		alive_flag=true;
 #ifndef GLIB_DISPATCHER_BROKEN
@@ -686,10 +686,12 @@ public:
 AsyncRenderer::AsyncRenderer(etl::handle<synfig::Target> target_,synfig::ProgressCallback *cb):
 	error(false),
 	success(false),
-	cb(cb)
+	cb(cb),
 #ifdef SINGLE_THREADED
-	, updating(false)
+	updating(false),
 #endif
+	start_time(0, 0),
+	finish_time(0, 0)
 {
 	render_thread=0;
 	if(etl::handle<synfig::Target_Tile>::cast_dynamic(target_))
@@ -765,6 +767,8 @@ AsyncRenderer::stop()
 #endif
 				render_thread->join();
 #endif
+			finish_time.assign_current_time();
+
 
 			// Make sure all the dispatch crap is cleared out
 			//Glib::MainContext::get_default()->iteration(false);
@@ -772,10 +776,12 @@ AsyncRenderer::stop()
 			if(success)
 				signal_success_();
 
-			signal_finished_();
-
 			target=0;
 			render_thread=0;
+			
+			lock.release();
+			
+			signal_finished_();
 		}
 	}
 }
@@ -793,6 +799,8 @@ AsyncRenderer::resume()
 void
 AsyncRenderer::start()
 {
+	start_time.assign_current_time();
+	finish_time = start_time;
 	done_connection=Glib::signal_timeout().connect(
 		sigc::bind_return(
 			mem_fun(*this,&AsyncRenderer::start_),
