@@ -152,7 +152,7 @@ void studio::Widget_NavView::on_start_render()
 			etl::handle<Target_Cairo> targ = cairo_image_target(&cairo_surface);
 			// Fill the target with the proper information
 			targ->set_canvas(get_canvas_view()->get_canvas());
-			targ->set_remove_alpha();
+			targ->set_alpha_mode(TARGET_ALPHA_MODE_FILL);
 			targ->set_avoid_time_sync();
 			targ->set_quality(get_canvas_view()->get_work_area()->get_quality());
 			targ->set_rend_desc(&r);
@@ -165,7 +165,7 @@ void studio::Widget_NavView::on_start_render()
 			etl::handle<Target_Scanline>	targ = surface_target(surface.get());
 			// Fill the target with the proper information
 			targ->set_canvas(get_canvas_view()->get_canvas());
-			targ->set_remove_alpha();
+			targ->set_alpha_mode(TARGET_ALPHA_MODE_FILL);
 			targ->set_avoid_time_sync();
 			targ->set_quality(get_canvas_view()->get_work_area()->get_quality());
 			targ->set_rend_desc(&r);
