@@ -46,6 +46,7 @@
 #include "widgets/widget_timeslider.h"
 #include "widgets/widget_keyframe_list.h"
 #include "general.h"
+#include "trees/layertree.h"
 #include <synfig/timepointcollect.h>
 
 #endif
@@ -81,8 +82,18 @@ public:
 
 	TimeTrackView()
 	{
+		//Text attributes must be the same that layer param tree's to have aligned rows
+		Pango::AttrList attr_list;
+		{
+			Pango::AttrInt pango_size(Pango::Attribute::create_attr_size(Pango::SCALE*8));
+			pango_size.set_start_index(0);
+			pango_size.set_end_index(64);
+			attr_list.change(pango_size);
+		}
+
 		int label_index(append_column_editable(_("Name"),model.label));
 		Gtk::TreeView::Column* label_column = get_column(label_index-1);
+		label_column->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
 
 		{	// --- T I M E   T R A C K --------------------------------------------
 			Gtk::TreeView::Column* column = Gtk::manage( new Gtk::TreeView::Column(_("Time Track")) );
@@ -98,10 +109,29 @@ public:
 
 			//column->pack_start(*cellrenderer_time_track);
 
+			// Add a fixed size (same that layer param tree) empty text renderer
+			// to align the rows with params dock when the text is taller than value_type icons height
+			Gtk::CellRendererText* text_cellrenderer = Gtk::manage( new Gtk::CellRendererText() );
+			text_cellrenderer->property_attributes()=attr_list;
+			column->pack_end(*text_cellrenderer,false);
+			text_cellrenderer->set_fixed_size (0,-1);
+
+			// Add a fixed size (1pixel widht, same height than value_type icon) empty (alpha) icon
+			// to align the rows with params dock when the text is smaller than value_type icons height
+			Gtk::CellRendererPixbuf* icon_cellrenderer = Gtk::manage( new Gtk::CellRendererPixbuf() );
+			column->pack_end(*icon_cellrenderer,false);
+			Glib::RefPtr<Gdk::Pixbuf> pixbuf;
+			pixbuf=Gtk::Button().render_icon(Gtk::StockID("synfig-utils_timetrack_align"),Gtk::ICON_SIZE_SMALL_TOOLBAR);
+			icon_cellrenderer->property_pixbuf() = pixbuf;
+			icon_cellrenderer->set_fixed_size (0,-1);
+
 			// Finish setting up the column
 			column->set_reorderable();
+			column->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
 			column->set_resizable();
-			column->set_min_width(200);
+// Commented during Align rows fixing
+// http://www.synfig.org/issues/thebuggenie/synfig/issues/161
+// 			column->set_min_width(200);
 
 			append_column(*column);
 		}
@@ -325,7 +355,8 @@ public:
 
 			if(adjustment.get_page_size()>get_height())
 				adjustment.set_page_size(get_height());
-
+/* Commented during Align rows fixing
+// http://www.synfig.org/issues/thebuggenie/synfig/issues/161
 			int row_height = 0;
 			if(getenv("SYNFIG_TIMETRACK_ROW_HEIGHT"))
 				row_height = atoi(getenv("SYNFIG_TIMETRACK_ROW_HEIGHT"));
@@ -333,6 +364,7 @@ public:
 				row_height = 18;
 
 			cellrenderer_time_track->set_fixed_size(-1,row_height);
+*/
 		}
 	}
 
@@ -376,9 +408,12 @@ Dock_Timetrack::Dock_Timetrack():
 	widget_kf_list_= new Widget_Keyframe_List();
 
 	int header_height = 0;
+/* Commented during Align rows fixing
+// http://www.synfig.org/issues/thebuggenie/synfig/issues/161
 	if(getenv("SYNFIG_TIMETRACK_HEADER_HEIGHT"))
 		header_height = atoi(getenv("SYNFIG_TIMETRACK_HEADER_HEIGHT"));
 	if (header_height < 3)
+*/
 		header_height = 24;
 
 	widget_timeslider_->set_size_request(-1,header_height-header_height/3+1);
@@ -416,6 +451,13 @@ Dock_Timetrack::init_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_view
 
 	tree_view->signal_waypoint_clicked_timetrackview.connect(sigc::mem_fun(*canvas_view, &studio::CanvasView::on_waypoint_clicked_canvasview));
 
+	studio::LayerTree* tree_layer(dynamic_cast<studio::LayerTree*>(canvas_view->get_ext_widget("layers_cmp")));
+
+	/*
+	if(!getenv("SYNFIG_TIMETRACK_HEADER_HEIGHT"))
+	*/
+	tree_layer->signal_param_tree_header_height_changed().connect(sigc::mem_fun(*this, &studio::Dock_Timetrack::on_update_header_height));
+
 	canvas_view->time_adjustment().signal_value_changed().connect(sigc::mem_fun(*tree_view,&Gtk::TreeView::queue_draw));
 	canvas_view->time_adjustment().signal_changed().connect(sigc::mem_fun(*tree_view,&Gtk::TreeView::queue_draw));
 
@@ -474,11 +516,17 @@ Dock_Timetrack::changed_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_v
 	if(canvas_view)
 	{
 		TimeTrackView* tree_view(dynamic_cast<TimeTrackView*>(canvas_view->get_ext_widget(get_name())));
-	Gtk::TreeView* param_tree_view(dynamic_cast<Gtk::TreeView*>(canvas_view->get_ext_widget("params")));
-	tree_view->set_vadjustment(*param_tree_view->get_vadjustment());
+		Gtk::TreeView* param_tree_view(dynamic_cast<Gtk::TreeView*>(canvas_view->get_ext_widget("params")));
+		tree_view->set_vadjustment(*param_tree_view->get_vadjustment());
 
 		assert(tree_view);
-
+		// Fixed size drawing areas to align the widget_timeslider and tree_view time cursors
+		// TODO ?: one align_drawingArea.(0, 1, 0, 1) modify_bg KF's color another (0, 1, 1, 2) modify_bg TS's color
+		Gtk::DrawingArea* align_drawingArea1 = Gtk::manage(new Gtk::DrawingArea);
+		align_drawingArea1->set_size_request(2,-1);
+		// TODO ?: one align_drawingArea.(2, 3, 0, 1) modify_bg KF's color another (2, 3, 1, 2) modify_bg TS's color
+		Gtk::DrawingArea* align_drawingArea2 = Gtk::manage(new Gtk::DrawingArea);
+		align_drawingArea2->set_size_request(6,-1);
 
 		widget_timeslider_->set_time_adjustment(&canvas_view->time_adjustment());
 		widget_timeslider_->set_bounds_adjustment(&canvas_view->time_window_adjustment());
@@ -489,12 +537,34 @@ Dock_Timetrack::changed_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_v
 
 		vscrollbar_->set_adjustment(*tree_view->get_vadjustment());
 		hscrollbar_->set_adjustment(canvas_view->time_window_adjustment());
-		table_=new Gtk::Table(2,3);
-		table_->attach(*widget_timeslider_, 0, 1, 1, 2, Gtk::FILL|Gtk::SHRINK, Gtk::FILL|Gtk::SHRINK);
-		table_->attach(*widget_kf_list_, 0, 1, 0, 1, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::SHRINK);
-		table_->attach(*tree_view, 0, 1, 2, 3, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::EXPAND);
-		table_->attach(*hscrollbar_, 0, 1, 3, 4, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::SHRINK);
-		table_->attach(*vscrollbar_, 1, 2, 0, 3, Gtk::FILL|Gtk::SHRINK, Gtk::FILL|Gtk::EXPAND);
+
+/*
+	0------1------2------3------4
+	|  A   |  KF  |  A   |  v   |
+	|  L   |      |  L   |  s   |
+	1--I---x------x--I---x--c---x
+	|  G   |  TS  |  G   |  r   |
+	|  N1  |      |  N2  |  o   |
+	2------x------x------x--l---x
+	|  TV  |  TV  |  TV  |  l   |
+	|      |      |      |  b   |
+	3------x------x------x------x
+	| hscrollbar
+
+KF = widget_kf_list
+TS = widget_timeslider
+TV = tree_view
+ALIGN1 = align_drawingArea1
+ALIGN2 = align_drawingArea2
+*/
+		table_=new Gtk::Table(3,4);
+		table_->attach(*align_drawingArea1, 0, 1, 0, 2, Gtk::SHRINK, Gtk::FILL);
+		table_->attach(*widget_kf_list_, 1, 2, 0, 1, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::SHRINK);
+		table_->attach(*widget_timeslider_, 1, 2, 1, 2, Gtk::FILL|Gtk::SHRINK, Gtk::FILL|Gtk::SHRINK);
+		table_->attach(*align_drawingArea2, 2, 3, 0, 2, Gtk::SHRINK, Gtk::FILL);
+		table_->attach(*tree_view, 0, 3, 2, 3, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::EXPAND);
+		table_->attach(*hscrollbar_, 0, 3, 3, 4, Gtk::FILL|Gtk::EXPAND, Gtk::FILL|Gtk::SHRINK);
+		table_->attach(*vscrollbar_, 3, 4, 0, 3, Gtk::FILL|Gtk::SHRINK, Gtk::FILL|Gtk::EXPAND);
 		add(*table_);
 
 		//add(*last_widget_curves_);
@@ -506,3 +576,21 @@ Dock_Timetrack::changed_canvas_view_vfunc(etl::loose_handle<CanvasView> canvas_v
 		//clear_previous();
 	}
 }
+
+void
+Dock_Timetrack::on_update_header_height( int header_height)
+{
+	// FIXME very bad hack (curves dock also contains this)
+	//! Adapt the border size "according" to different windows manager rendering
+#ifdef WIN32
+	header_height-=2;
+#elif defined(__APPLE__)
+	header_height+=6;
+#else
+// *nux and others
+	header_height+=2;
+#endif
+
+	widget_timeslider_->set_size_request(-1,header_height-header_height/3+1);
+	widget_kf_list_->set_size_request(-1,header_height/3+1);
+}
