@@ -64,6 +64,11 @@ public:
 
 	Dock_Timetrack();
 	~Dock_Timetrack();
+
+private:
+	//! Signal handler for studio::LayerTree::signal_param_tree_header_height_changed
+	/* \see studio::LayerTree::signal_param_tree_header_height_changed */
+	void on_update_header_height( int header_height);
 }; // END of Dock_Timetrack
 
 }; // END of namespace studio
