@@ -98,9 +98,9 @@ class studio::StateBLine_Context : public sigc::trackable
 	std::list<synfig::ValueNode_Const::Handle> bline_point_list;
 	synfigapp::Settings& settings;
 
-	bool on_vertex_change(const synfig::Point &point, synfig::ValueNode_Const::Handle value_node);
-	bool on_tangent1_change(const synfig::Point &point, synfig::ValueNode_Const::Handle value_node);
-	bool on_tangent2_change(const synfig::Point &point, synfig::ValueNode_Const::Handle value_node);
+	bool on_vertex_change(const studio::Duck &duck, synfig::ValueNode_Const::Handle value_node);
+	bool on_tangent1_change(const studio::Duck &duck, synfig::ValueNode_Const::Handle value_node);
+	bool on_tangent2_change(const studio::Duck &duck, synfig::ValueNode_Const::Handle value_node);
 
 
 	void popup_handle_menu(synfig::ValueNode_Const::Handle value_node);
@@ -584,7 +584,7 @@ StateBLine_Context::run_()
 		ValueNode_BLine::Handle value_node_bline(ValueNode_BLine::create(new_list));
 		assert(value_node_bline);
 
-		ValueNode_Const::Handle value_node_origin(ValueNode_Const::create(Vector()));
+		ValueNode::Handle value_node_origin(ValueNode_Const::create(Vector()));
 		assert(value_node_origin);
 
 		// Set the looping flag
@@ -985,7 +985,7 @@ StateBLine_Context::event_mouse_release_handler(const Smach::event& /*x*/)
 {
 	if(curr_duck)
 	{
-		curr_duck->signal_edited()(curr_duck->get_point());
+		curr_duck->signal_edited()(*curr_duck);
 		if(next_duck)
 		{
 			curr_duck=next_duck;
@@ -1013,7 +1013,7 @@ StateBLine_Context::event_mouse_click_handler(const Smach::event& x)
 			bline_point.set_origin(0.5f);
 			bline_point.set_split_tangent_flag(false);
 			bline_point.set_tangent1(Vector(0,0));
-			bline_point_list.push_back(ValueNode_Const::create(bline_point));
+			bline_point_list.push_back(ValueNode_Const::Handle::cast_dynamic(ValueNode_Const::create(bline_point)));
 
 			refresh_ducks();
 			return Smach::RESULT_ACCEPT;
@@ -1232,28 +1232,28 @@ StateBLine_Context::refresh_ducks(bool button_down)
 
 
 bool
-StateBLine_Context::on_vertex_change(const synfig::Point &point, synfig::ValueNode_Const::Handle value_node)
+StateBLine_Context::on_vertex_change(const studio::Duck &duck, synfig::ValueNode_Const::Handle value_node)
 {
 	BLinePoint bline_point(value_node->get_value().get(BLinePoint()));
-	bline_point.set_vertex(point);
+	bline_point.set_vertex(duck.get_point());
 	value_node->set_value(bline_point);
 	return true;
 }
 
 bool
-StateBLine_Context::on_tangent1_change(const synfig::Point &point, synfig::ValueNode_Const::Handle value_node)
+StateBLine_Context::on_tangent1_change(const studio::Duck &duck, synfig::ValueNode_Const::Handle value_node)
 {
 	BLinePoint bline_point(value_node->get_value().get(BLinePoint()));
-	bline_point.set_tangent1(point);
+	bline_point.set_tangent1(duck.get_point());
 	value_node->set_value(bline_point);
 	return true;
 }
 
 bool
-StateBLine_Context::on_tangent2_change(const synfig::Point &point, synfig::ValueNode_Const::Handle value_node)
+StateBLine_Context::on_tangent2_change(const studio::Duck &duck, synfig::ValueNode_Const::Handle value_node)
 {
 	BLinePoint bline_point(value_node->get_value().get(BLinePoint()));
-	bline_point.set_tangent2(point);
+	bline_point.set_tangent2(duck.get_point());
 	value_node->set_value(bline_point);
 	return true;
 }
@@ -1375,8 +1375,8 @@ StateBLine_Context::bline_insert_vertex(synfig::ValueNode_Const::Handle value_no
 			bline_point.set_tangent2(bline_point.get_tangent1());
 			bline_point.set_split_tangent_flag(false);
 			bline_point.set_origin(origin);
+			bline_point_list.insert(iter,ValueNode_Const::Handle::cast_dynamic(ValueNode_Const::create(bline_point)));
 
-			bline_point_list.insert(iter,ValueNode_Const::create(bline_point));
 			break;
 		}
 
