@@ -268,6 +268,7 @@ LayerTree::create_layer_tree()
 Gtk::Widget*
 LayerTree::create_param_tree()
 {
+	//Text attributes must be the same that TimeTrackView tree's to have aligned rows
 	Pango::AttrList attr_list;
 	{
 		Pango::AttrInt pango_size(Pango::Attribute::create_attr_size(Pango::SCALE*8));
@@ -281,6 +282,12 @@ LayerTree::create_param_tree()
 	{	// --- N A M E --------------------------------------------------------
 		Gtk::TreeView::Column* column = Gtk::manage( new Gtk::TreeView::Column(_("Name")) );
 
+		// Affect a widget to the first column button to retrieve it when style is updated
+		Gtk::Label* columnzero_label = Gtk::manage( new Gtk::Label() );
+		columnzero_label->set_text(column->get_title());
+		column->set_widget(*columnzero_label);
+		columnzero_label->show();
+
 		// Set up the icon cell-renderer
 		Gtk::CellRendererPixbuf* icon_cellrenderer = Gtk::manage( new Gtk::CellRendererPixbuf() );
 		column->pack_start(*icon_cellrenderer,false);
@@ -387,8 +394,10 @@ LayerTree::create_param_tree()
 
 		// Finish setting up the column
 		column->set_reorderable();
+		column->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
 		column->set_resizable();
-		column->set_min_width(200);
+// Commented during Align attempt
+//		column->set_min_width(200);
 
 		if (!getenv("SYNFIG_DISABLE_PARAMS_PANEL_TIMETRACK"))
 			get_param_tree_view().append_column(*column);
@@ -403,6 +412,16 @@ LayerTree::create_param_tree()
 
 	get_param_tree_view().signal_event().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_tree_event));
 	get_param_tree_view().signal_query_tooltip().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_tree_view_query_tooltip));
+	// Column widget label event used to retrieve column size
+	Gtk::Widget* columnzero_label = get_param_tree_view().get_column(0)->get_widget ();
+	/* GTKMM 3 remplacement for columnzero_label signal_style_changed
+	columnzero_label->signal_style_updated().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_tree_column_label_style_updated));
+	*/
+	columnzero_label->signal_style_changed().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_tree_column_label_style_changed));
+	/* GTKMM 3 remplacement for columnzero_label signal_expose_event
+	columnzero_label->signal_draw().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_tree_column_label_draw));
+	*/
+	columnzero_label->signal_expose_event().connect(sigc::mem_fun(*this, &studio::LayerTree::on_param_tree_column_label_expose_draw));
 	get_param_tree_view().show();
 
 	Gtk::ScrolledWindow *scroll = manage(new class Gtk::ScrolledWindow());
@@ -412,6 +431,10 @@ LayerTree::create_param_tree()
 	scroll->set_shadow_type(Gtk::SHADOW_ETCHED_IN);
 	scroll->show();
 
+	// To get the initial style
+	param_tree_style_changed = true;
+	param_tree_header_height = 0;
+
 	//column_time_track->set_visible(false);
 
 	return scroll;
@@ -1277,3 +1300,77 @@ LayerTree::on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context,
 	context->drag_finish(false, false, time);
 }
 */
+
+// GTKMM 3 remplacement for on_param_tree_column_label_style_changed
+//void
+//LayerTree::on_param_tree_column_label_style_updated ()
+//{
+//	param_tree_style_changed = true;
+//}
+
+void
+LayerTree::on_param_tree_column_label_style_changed (const Glib::RefPtr< Gtk::Style >& /*previous_style*/)
+{
+	param_tree_style_changed = true;
+}
+
+// GTKMM 3 remplacement for on_param_tree_column_label_expose_draw
+//bool
+//LayerTree::on_param_tree_column_label_draw (const ::Cairo::RefPtr< ::Cairo::Context>& /*cr*/)
+//{
+//	if (param_tree_style_changed)
+//	{
+//		if (update_param_tree_header_height())	signal_param_tree_header_height_changed()(param_tree_header_height);
+//		param_tree_style_changed = false;
+//	}
+//	return true;
+//}
+
+bool
+LayerTree::on_param_tree_column_label_expose_draw (GdkEventExpose * /*event*/)
+{
+	if (param_tree_style_changed)
+	{
+		if (update_param_tree_header_height())	signal_param_tree_header_height_changed()(param_tree_header_height);
+		param_tree_style_changed = false;
+	}
+	//tell gtkmm to pass (x window) signal to the next signal handler
+	return false;
+}
+
+bool
+LayerTree::update_param_tree_header_height()
+{
+	bool header_height_updated = false;
+	const Gtk::TreeViewColumn* column = get_param_tree_view().get_column (0);
+	if (column)
+	{
+		if(column->get_widget())
+		{
+			if(column->get_widget()->get_parent())
+			{
+				const Gtk::Container* container;
+				if((container = column->get_widget()->get_parent()->get_parent()))
+				{
+					int header_height = container->get_height();
+					if (header_height != param_tree_header_height)
+					{
+						param_tree_header_height = header_height;
+						header_height_updated = true;
+					}
+				}
+				else
+				{
+					int header_height = column->get_widget()->get_parent()->get_height();
+					if (header_height != param_tree_header_height)
+					{
+						param_tree_header_height = header_height;
+						header_height_updated = true;
+					}
+				}
+
+			}
+		}
+	}
+	return header_height_updated;
+}
