@@ -2955,7 +2955,11 @@ studio::WorkArea::async_update_finished()
 	{
 		dirty=false;
 		//queued=false;
-		cb->task(_("Idle"));
+		String text(_("Idle"));
+		String text2(_("Last rendering time"));
+		Real execution_time = async_renderer ? async_renderer->get_execution_time() : 0.0;
+		if (execution_time > 0) text += strprintf(" (%s = %f %s)", text2.c_str(), execution_time, _("sec"));
+		cb->task(text);
 	}
 	else
 	{
