@@ -2,7 +2,7 @@
 /*!	\file activepointseton.cpp
 **	\brief Template File
 **
-**	$Id: activepointseton.cpp 2098 2008-10-14 21:00:21Z genete $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -54,13 +54,13 @@ using namespace Action;
 /* === M A C R O S ========================================================= */
 
 ACTION_INIT(Action::ActivepointSetOn);
-ACTION_SET_NAME(Action::ActivepointSetOn,"activepoint_set_on");
+ACTION_SET_NAME(Action::ActivepointSetOn,"ActivepointSetOn");
 ACTION_SET_LOCAL_NAME(Action::ActivepointSetOn,N_("Mark Activepoint as \"On\""));
 ACTION_SET_TASK(Action::ActivepointSetOn,"set_on");
 ACTION_SET_CATEGORY(Action::ActivepointSetOn,Action::CATEGORY_ACTIVEPOINT|Action::CATEGORY_VALUEDESC);
 ACTION_SET_PRIORITY(Action::ActivepointSetOn,-10);
 ACTION_SET_VERSION(Action::ActivepointSetOn,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointSetOn,"$Id: activepointseton.cpp 2098 2008-10-14 21:00:21Z genete $");
+ACTION_SET_CVS_ID(Action::ActivepointSetOn,"$Id$");
 
 /* === G L O B A L S ======================================================= */
 
